'use strict';

function setupContentsRoutingService(routingTab, routingInfo) {
    const handler = (data) => {
        updateContentsRoutingService(routingTab, data);
    };

    noraapi.addEventHandler(
        "update_status_" + routingInfo.webSocketRoomId,
        handler
    );
}

function updateContentsRoutingService(routingTab, data) {
    logger.trace(
        "Update contents routing service.\n" +
        JSON.stringify(data)
    );

    const routingServiceContents =
        getContentsRoutingService(routingTab, data.webSocketRoomId, data);

    routingServiceContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.routing_type'))
        .text(data.routingServiceType);
//    routingServiceContents
//        .find('#' + selectorEscape(data.webSocketRoomId + '.status'))
//        .text(data.routingServiceStatus);

    const $servers = routingServiceContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.servers'));
    if($servers.exists()){
        $servers.empty();

        $.each(data.routingServiceStatus, (index, status) =>{
            const $serverEntries = $('<tr />');

            $serverEntries.append([
                $('<th />',{
                    "name" : 'index',
                    "scope" : "row",
                    "html" : index + 1
                }),
                $('<td />' ,{
                    "name" : "address",
                    "html" : htmlEntities(status.serverAddress) + ":" + htmlEntities(status.serverPort)
                }),
                $('<td />' ,{
                    "name" : "status",
                    "html" : htmlEntities(status.serviceStatus)
                })
            ]);

            $servers.append($serverEntries);
        });
    }

    if(data.routingServiceType === 'ircDDB'){
        updateContentsRoutingServiceIrcDDB(routingTab, data);
    }
}

function updateContentsRoutingServiceIrcDDB(routingServiceContents, data) {
    routingServiceContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.user_records'))
        .text(data.userRecords);

    routingServiceContents
        .find('#' + selectorEscape(data.webSocketRoomId + '.repeater_records'))
        .text(data.repeaterRecords);
}

function getContentsRoutingService(routingtab, functionID, data) {
    let routingServiceContents =
        $(routingtab).find(
            "[contents-id=" + selectorEscape(functionID) + "]"
        );
    if(!routingServiceContents.exists()){
        routingServiceContents =
            routingtab.loadTemplate($("#template_routing_service"),{
                "routing_type_id" : functionID + '.routing_type',
                "status_id" : functionID + '.status',
                "servers_id" : functionID + '.servers'
            });

        if(data.routingServiceType === 'ircDDB'){
            routingServiceContents.find('.row').loadTemplate(
                $('#template_routing_service_addtional_information'),{
                    'title' : 'User Records',
                    'content_id' : functionID + '.user_records'
                },
                {'append':true}
            );
            routingServiceContents.find('.row').loadTemplate(
                $('#template_routing_service_addtional_information'),{
                    'title' : 'Repeater Records',
                    'content_id' : functionID + '.repeater_records'
                },
                {'append':true}
            );
        }

        localizeContent(routingtab);
    }

    return routingServiceContents;
}
